cadctap 
========

.. image:: https://img.shields.io/pypi/v/cadctap.svg
    :target: https://pypi.python.org/pypi/cadctap

Canadian Astronomy Data Centre - TAP access

client for interacting with catalog Web services hosted at the Canadian
Astronomy Data Centre
